@@ -769,7 +769,7 @@ if ($go_sql) {
             $cfgBookmark['user'],
             $_POST['sql_query'],
             $_POST['bkm_label'],
-            isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
+            isset($_POST['bkm_replace'])
         );
     }
 
@@ -785,7 +785,7 @@ if ($go_sql) {
             $cfgBookmark['user'],
             $_POST['sql_query'],
             $_POST['bkm_label'],
-            isset($_POST['bkm_replace']) ? $_POST['bkm_replace'] : null
+            isset($_POST['bkm_replace'])
         );
     }
 
