@@ -337,11 +337,13 @@ RTE.COMMON = {
                 that.$ajaxDialog = $('<div id="rteDialog">' + data.message + '</div>').dialog({
                     width: 700,
                     minWidth: 500,
-                    maxHeight: $(window).height(),
                     buttons: that.buttonOptions,
-                    title: data.title,
+                    // Issue #15810 - use button titles for modals (eg: new procedure)
+                    // Respect the order: title on href tag, href content, title sent in response
+                    title: $this.attr('title') || $this.text() || $(data.title).text(),
                     modal: true,
                     open: function () {
+                        $('#rteDialog').dialog('option', 'max-height', $(window).height());
                         if ($('#rteDialog').parents('.ui-dialog').height() > $(window).height()) {
                             $('#rteDialog').dialog('option', 'height', $(window).height());
                         }
