@@ -785,7 +785,8 @@ class FormDisplay
         }
         return Util::getDocuLink(
             'config',
-            'cfg_' . $this->_getOptName($path)
+            'cfg_' . $this->_getOptName($path),
+            Sanitize::isSetup() ? '../' : ''
         );
     }
 
@@ -817,7 +818,7 @@ class FormDisplay
         $userPrefsDisallow = $GLOBALS['PMA_Config']->get('is_setup')
             ? $this->_configFile->get('UserprefsDisallow', [])
             : $GLOBALS['cfg']['UserprefsDisallow'];
-        $this->_userprefsDisallow = array_flip($userPrefsDisallow);
+        $this->_userprefsDisallow = array_flip($userPrefsDisallow ?? []);
     }
 
     /**
