@@ -5,8 +5,14 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Config\Forms\Page;
 
+/**
+ * Class ExportForm
+ * @package PhpMyAdmin\Config\Forms\Page
+ */
 class ExportForm extends \PhpMyAdmin\Config\Forms\User\ExportForm
 {
 }
