@@ -5,19 +5,31 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Config\Forms\User;
 
 use PhpMyAdmin\Config\Forms\BaseFormList;
 
+/**
+ * Class UserFormList
+ * @package PhpMyAdmin\Config\Forms\User
+ */
 class UserFormList extends BaseFormList
 {
-    protected static $all = array(
+    /**
+     * @var array
+     */
+    protected static $all = [
         'Features',
         'Sql',
         'Navi',
         'Main',
-        'Import',
         'Export',
-    );
+        'Import',
+    ];
+    /**
+     * @var string
+     */
     protected static $ns = '\\PhpMyAdmin\\Config\\Forms\\User\\';
 }
