@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Display;
 
 use PhpMyAdmin\Core;
@@ -17,8 +19,8 @@ use PhpMyAdmin\Relation;
 use PhpMyAdmin\Response;
 use PhpMyAdmin\Table;
 use PhpMyAdmin\Template;
-use PhpMyAdmin\Url;
 use PhpMyAdmin\Util;
+use Throwable;
 
 /**
  * PhpMyAdmin\Display\Export class
@@ -28,16 +30,22 @@ use PhpMyAdmin\Util;
 class Export
 {
     /**
-     * @var Relation $relation
+     * @var Relation
      */
     private $relation;
 
+    /**
+     * @var Template
+     */
+    public $template;
+
     /**
      * Constructor
      */
     public function __construct()
     {
-        $this->relation = new Relation();
+        $this->relation = new Relation($GLOBALS['dbi']);
+        $this->template = new Template();
     }
 
     /**
@@ -62,11 +70,11 @@ class Export
      */
     public function getHtmlForSelectOptions($tmpSelect = '')
     {
-        // Check if the selected databases are defined in $_GET
+        // Check if the selected databases are defined in $_POST
         // (from clicking Back button on export.php)
-        if (isset($_GET['db_select'])) {
-            $_GET['db_select'] = urldecode($_GET['db_select']);
-            $_GET['db_select'] = explode(",", $_GET['db_select']);
+        if (isset($_POST['db_select'])) {
+            $_POST['db_select'] = urldecode($_POST['db_select']);
+            $_POST['db_select'] = explode(",", $_POST['db_select']);
         }
 
         $databases = [];
@@ -75,11 +83,11 @@ class Export
                 continue;
             }
             $isSelected = false;
-            if (isset($_GET['db_select'])) {
-                if (in_array($currentDb, $_GET['db_select'])) {
+            if (isset($_POST['db_select'])) {
+                if (in_array($currentDb, $_POST['db_select'])) {
                     $isSelected = true;
                 }
-            } elseif (!empty($tmpSelect)) {
+            } elseif (! empty($tmpSelect)) {
                 if (mb_strpos(
                     ' ' . $tmpSelect,
                     '|' . $currentDb . '|'
@@ -95,7 +103,7 @@ class Export
             ];
         }
 
-        return Template::get('display/export/select_options')->render([
+        return $this->template->render('display/export/select_options', [
             'databases' => $databases,
         ]);
     }
@@ -121,24 +129,24 @@ class Export
         global $cfg;
 
         // If the export method was not set, the default is quick
-        if (isset($_GET['export_method'])) {
-            $cfg['Export']['method'] = $_GET['export_method'];
+        if (isset($_POST['export_method'])) {
+            $cfg['Export']['method'] = $_POST['export_method'];
         } elseif (! isset($cfg['Export']['method'])) {
             $cfg['Export']['method'] = 'quick';
         }
 
-        if (empty($sqlQuery) && isset($_GET['sql_query'])) {
-            $sqlQuery = $_GET['sql_query'];
+        if (empty($sqlQuery) && isset($_POST['sql_query'])) {
+            $sqlQuery = $_POST['sql_query'];
         }
 
-        return Template::get('display/export/hidden_inputs')->render([
+        return $this->template->render('display/export/hidden_inputs', [
             'db' => $db,
             'table' => $table,
             'export_type' => $exportType,
             'export_method' => $cfg['Export']['method'],
             'single_table' => $singleTable,
             'sql_query' => $sqlQuery,
-            'template_id' => isset($_GET['template_id']) ? $_GET['template_id'] : '',
+            'template_id' => isset($_POST['template_id']) ? $_POST['template_id'] : '',
         ]);
     }
 
@@ -174,9 +182,9 @@ class Export
             }
         }
 
-        return Template::get('display/export/template_options')->render([
+        return $this->template->render('display/export/template_options', [
             'templates' => $templates,
-            'selected_template' => !empty($_GET['template_id']) ? $_GET['template_id'] : null,
+            'selected_template' => ! empty($_POST['template_id']) ? $_POST['template_id'] : null,
         ]);
     }
 
@@ -188,13 +196,13 @@ class Export
     private function getHtmlForOptionsMethod()
     {
         global $cfg;
-        if (isset($_GET['quick_or_custom'])) {
-            $exportMethod = $_GET['quick_or_custom'];
+        if (isset($_POST['quick_or_custom'])) {
+            $exportMethod = $_POST['quick_or_custom'];
         } else {
             $exportMethod = $cfg['Export']['method'];
         }
 
-        return Template::get('display/export/method')->render([
+        return $this->template->render('display/export/method', [
             'export_method' => $exportMethod,
         ]);
     }
@@ -209,7 +217,7 @@ class Export
      */
     private function getHtmlForOptionsSelection($exportType, $multiValues)
     {
-        return Template::get('display/export/selection')->render([
+        return $this->template->render('display/export/selection', [
             'export_type' => $exportType,
             'multi_values' => $multiValues,
         ]);
@@ -225,7 +233,7 @@ class Export
     private function getHtmlForOptionsFormatDropdown($exportList)
     {
         $dropdown = Plugins::getChoice('Export', 'what', $exportList, 'format');
-        return Template::get('display/export/format_dropdown')->render([
+        return $this->template->render('display/export/format_dropdown', [
             'dropdown' => $dropdown,
         ]);
     }
@@ -242,7 +250,7 @@ class Export
         global $cfg;
         $options = Plugins::getOptions('Export', $exportList);
 
-        return Template::get('display/export/options_format')->render([
+        return $this->template->render('display/export/options_format', [
             'options' => $options,
             'can_convert_kanji' => Encoding::canConvertKanji(),
             'exec_time_limit' => $cfg['ExecTimeLimit'],
@@ -263,10 +271,10 @@ class Export
         $tableObject = new Table($table, $db);
         $numberOfRows = $tableObject->countRecords();
 
-        return Template::get('display/export/options_rows')->render([
-            'allrows' => isset($_GET['allrows']) ? $_GET['allrows'] : null,
-            'limit_to' => isset($_GET['limit_to']) ? $_GET['limit_to'] : null,
-            'limit_from' => isset($_GET['limit_from']) ? $_GET['limit_from'] : null,
+        return $this->template->render('display/export/options_rows', [
+            'allrows' => isset($_POST['allrows']) ? $_POST['allrows'] : null,
+            'limit_to' => isset($_POST['limit_to']) ? $_POST['limit_to'] : null,
+            'limit_from' => isset($_POST['limit_from']) ? $_POST['limit_from'] : null,
             'unlim_num_rows' => $unlimNumRows,
             'number_of_rows' => $numberOfRows,
         ]);
@@ -288,7 +296,7 @@ class Export
             'quick_export_onserver_overwrite'
         );
 
-        return Template::get('display/export/options_quick_export')->render([
+        return $this->template->render('display/export/options_quick_export', [
             'save_dir' => $saveDir,
             'export_is_checked' => $exportIsChecked,
             'export_overwrite_is_checked' => $exportOverwriteIsChecked,
@@ -311,7 +319,7 @@ class Export
             'onserver_overwrite'
         );
 
-        return Template::get('display/export/options_output_save_dir')->render([
+        return $this->template->render('display/export/options_output_save_dir', [
             'save_dir' => $saveDir,
             'export_is_checked' => $exportIsChecked,
             'export_overwrite_is_checked' => $exportOverwriteIsChecked,
@@ -328,7 +336,7 @@ class Export
      */
     private function getHtmlForOptionsOutputFormat($exportType)
     {
-        $trans = new Message;
+        $trans = new Message();
         $trans->addText(__('@SERVER@ will become the server name'));
         if ($exportType == 'database' || $exportType == 'table') {
             $trans->addText(__(', @DATABASE@ will become the database name'));
@@ -357,8 +365,8 @@ class Export
         );
         $msg->addParamHtml('</a>');
 
-        if (isset($_GET['filename_template'])) {
-            $filenameTemplate = $_GET['filename_template'];
+        if (isset($_POST['filename_template'])) {
+            $filenameTemplate = $_POST['filename_template'];
         } else {
             if ($exportType == 'database') {
                 $filenameTemplate = $GLOBALS['PMA_Config']->getUserValue(
@@ -378,7 +386,7 @@ class Export
             }
         }
 
-        return Template::get('display/export/options_output_format')->render([
+        return $this->template->render('display/export/options_output_format', [
             'message' => $msg->getMessage(),
             'filename_template' => $filenameTemplate,
             'is_checked' => $this->checkboxCheck('remember_file_template'),
@@ -394,7 +402,7 @@ class Export
     {
         global $cfg;
 
-        return Template::get('display/export/options_output_charset')->render([
+        return $this->template->render('display/export/options_output_charset', [
             'encodings' => Encoding::listEncodings(),
             'export_charset' => $cfg['Export']['charset'],
         ]);
@@ -408,8 +416,8 @@ class Export
     private function getHtmlForOptionsOutputCompression()
     {
         global $cfg;
-        if (isset($_GET['compression'])) {
-            $selectedCompression = $_GET['compression'];
+        if (isset($_POST['compression'])) {
+            $selectedCompression = $_POST['compression'];
         } elseif (isset($cfg['Export']['compression'])) {
             $selectedCompression = $cfg['Export']['compression'];
         } else {
@@ -427,7 +435,7 @@ class Export
         $isZip = ($cfg['ZipDump'] && function_exists('gzcompress'));
         $isGzip = ($cfg['GZipDump'] && function_exists('gzencode'));
 
-        return Template::get('display/export/options_output_compression')->render([
+        return $this->template->render('display/export/options_output_compression', [
             'is_zip' => $isZip,
             'is_gzip' => $isGzip,
             'selected_compression' => $selectedCompression,
@@ -441,8 +449,8 @@ class Export
      */
     private function getHtmlForOptionsOutputRadio()
     {
-        return Template::get('display/export/options_output_radio')->render([
-            'has_repopulate' => isset($_GET['repopulate']),
+        return $this->template->render('display/export/options_output_radio', [
+            'has_repopulate' => isset($_POST['repopulate']),
             'export_asfile' => $GLOBALS['cfg']['Export']['asfile'],
         ]);
     }
@@ -458,7 +466,7 @@ class Export
     {
         $isChecked = $this->checkboxCheck('as_separate_files');
 
-        return Template::get('display/export/options_output_separate_files')->render([
+        return $this->template->render('display/export/options_output_separate_files', [
             'is_checked' => $isChecked,
             'export_type' => $exportType,
         ]);
@@ -476,14 +484,14 @@ class Export
         global $cfg;
 
         $hasAliases = isset($_SESSION['tmpval']['aliases'])
-            && !Core::emptyRecursive($_SESSION['tmpval']['aliases']);
+            && ! Core::emptyRecursive($_SESSION['tmpval']['aliases']);
         unset($_SESSION['tmpval']['aliases']);
 
         $isCheckedLockTables = $this->checkboxCheck('lock_tables');
         $isCheckedAsfile = $this->checkboxCheck('asfile');
 
         $optionsOutputSaveDir = '';
-        if (isset($cfg['SaveDir']) && !empty($cfg['SaveDir'])) {
+        if (isset($cfg['SaveDir']) && ! empty($cfg['SaveDir'])) {
             $optionsOutputSaveDir = $this->getHtmlForOptionsOutputSaveDir();
         }
         $optionsOutputFormat = $this->getHtmlForOptionsOutputFormat($exportType);
@@ -500,13 +508,13 @@ class Export
         }
         $optionsOutputRadio = $this->getHtmlForOptionsOutputRadio();
 
-        return Template::get('display/export/options_output')->render([
+        return $this->template->render('display/export/options_output', [
             'has_aliases' => $hasAliases,
             'export_type' => $exportType,
             'is_checked_lock_tables' => $isCheckedLockTables,
             'is_checked_asfile' => $isCheckedAsfile,
-            'repopulate' => isset($_GET['repopulate']),
-            'lock_tables' => isset($_GET['lock_tables']),
+            'repopulate' => isset($_POST['repopulate']),
+            'lock_tables' => isset($_POST['lock_tables']),
             'save_dir' => isset($cfg['SaveDir']) ? $cfg['SaveDir'] : null,
             'is_encoding_supported' => Encoding::isSupported(),
             'options_output_save_dir' => $optionsOutputSaveDir,
@@ -550,7 +558,7 @@ class Export
             $html .= $this->getHtmlForOptionsRows($db, $table, $unlimNumRows);
         }
 
-        if (isset($cfg['SaveDir']) && !empty($cfg['SaveDir'])) {
+        if (isset($cfg['SaveDir']) && ! empty($cfg['SaveDir'])) {
             $html .= $this->getHtmlForOptionsQuickExport();
         }
 
@@ -564,6 +572,10 @@ class Export
      * Generate Html For currently defined aliases
      *
      * @return string
+     * @throws Throwable
+     * @throws \Twig\Error\LoaderError
+     * @throws \Twig\Error\RuntimeError
+     * @throws \Twig\Error\SyntaxError
      */
     private function getHtmlForCurrentAlias()
     {
@@ -571,48 +583,51 @@ class Export
             . __('Defined aliases')
             . '</th></tr></thead><tbody>';
 
-        $template = Template::get('export/alias_item');
+        $template = $this->template->load('export/alias_item');
         if (isset($_SESSION['tmpval']['aliases'])) {
             foreach ($_SESSION['tmpval']['aliases'] as $db => $dbData) {
                 if (isset($dbData['alias'])) {
-                    $result .= $template->render(array(
+                    $result .= $template->render([
                         'type' => _pgettext('Alias', 'Database'),
                         'name' => $db,
                         'field' => 'aliases[' . $db . '][alias]',
                         'value' => $dbData['alias'],
-                    ));
+                    ]);
                 }
                 if (! isset($dbData['tables'])) {
                     continue;
                 }
                 foreach ($dbData['tables'] as $table => $tableData) {
                     if (isset($tableData['alias'])) {
-                        $result .= $template->render(array(
+                        $result .= $template->render([
                             'type' => _pgettext('Alias', 'Table'),
                             'name' => $db . '.' . $table,
                             'field' => 'aliases[' . $db . '][tables][' . $table . '][alias]',
                             'value' => $tableData['alias'],
-                        ));
+                        ]);
                     }
                     if (! isset($tableData['columns'])) {
                         continue;
                     }
                     foreach ($tableData['columns'] as $column => $columnName) {
-                        $result .= $template->render(array(
+                        $result .= $template->render([
                             'type' => _pgettext('Alias', 'Column'),
-                            'name' => $db . '.' . $table . '.'. $column,
+                            'name' => $db . '.' . $table . '.' . $column,
                             'field' => 'aliases[' . $db . '][tables][' . $table . '][colums][' . $column . ']',
                             'value' => $columnName,
-                        ));
+                        ]);
                     }
                 }
             }
         }
 
         // Empty row for javascript manipulations
-        $result .= '</tbody><tfoot class="hide">' . $template->render(array(
-            'type' => '', 'name' => '', 'field' => 'aliases_new', 'value' => ''
-        )) . '</tfoot>';
+        $result .= '</tbody><tfoot class="hide">' . $template->render([
+            'type' => '',
+            'name' => '',
+            'field' => 'aliases_new',
+            'value' => '',
+        ]) . '</tfoot>';
 
         return $result . '</table>';
     }
@@ -628,7 +643,7 @@ class Export
 
         $html = '<div id="alias_modal" class="hide" title="' . $title . '">';
         $html .= $this->getHtmlForCurrentAlias();
-        $html .= Template::get('export/alias_add')->render();
+        $html .= $this->template->render('export/alias_add');
 
         $html .= '</div>';
         return $html;
@@ -645,7 +660,7 @@ class Export
      * @param int    $unlimNumRows unlimited number of rows
      * @param string $multiValues  selector options
      *
-     * @return string $html
+     * @return string
      */
     public function getDisplay(
         $exportType,
@@ -658,19 +673,24 @@ class Export
     ) {
         $cfgRelation = $this->relation->getRelationsParam();
 
-        if (isset($_REQUEST['single_table'])) {
-            $GLOBALS['single_table'] = $_REQUEST['single_table'];
+        if (isset($_POST['single_table'])) {
+            $GLOBALS['single_table'] = $_POST['single_table'];
+        }
+
+        // Export a single table
+        if (isset($_GET['single_table'])) {
+            $GLOBALS['single_table'] = $_GET['single_table'];
         }
 
         /* Scan for plugins */
-        /* @var $exportList ExportPlugin[] */
+        /** @var ExportPlugin[] $exportList */
         $exportList = Plugins::getPlugins(
             "export",
             'libraries/classes/Plugins/Export/',
-            array(
+            [
                 'export_type' => $exportType,
-                'single_table' => isset($GLOBALS['single_table'])
-            )
+                'single_table' => isset($GLOBALS['single_table']),
+            ]
         );
 
         /* Fail if we didn't find any plugin */
@@ -681,14 +701,14 @@ class Export
             exit;
         }
 
-        $html = Template::get('display/export/option_header')->render([
+        $html = $this->template->render('display/export/option_header', [
             'export_type' => $exportType,
             'db' => $db,
             'table' => $table,
         ]);
 
         if ($cfgRelation['exporttemplateswork']) {
-            $html .= Template::get('display/export/template_loading')->render([
+            $html .= $this->template->render('display/export/template_loading', [
                 'options' => $this->getOptionsForTemplates($exportType),
             ]);
         }
@@ -731,8 +751,8 @@ class Export
      */
     public function handleTemplateActions(array $cfgRelation)
     {
-        if (isset($_REQUEST['templateId'])) {
-            $id = $GLOBALS['dbi']->escapeString($_REQUEST['templateId']);
+        if (isset($_POST['templateId'])) {
+            $id = $GLOBALS['dbi']->escapeString($_POST['templateId']);
         } else {
             $id = '';
         }
@@ -741,34 +761,34 @@ class Export
            . Util::backquote($cfgRelation['export_templates']);
         $user = $GLOBALS['dbi']->escapeString($GLOBALS['cfg']['Server']['user']);
 
-        switch ($_REQUEST['templateAction']) {
-        case 'create':
-            $query = "INSERT INTO " . $templateTable . "("
+        switch ($_POST['templateAction']) {
+            case 'create':
+                $query = "INSERT INTO " . $templateTable . "("
                 . " `username`, `export_type`,"
                 . " `template_name`, `template_data`"
                 . ") VALUES ("
                 . "'" . $user . "', "
-                . "'" . $GLOBALS['dbi']->escapeString($_REQUEST['exportType'])
-                . "', '" . $GLOBALS['dbi']->escapeString($_REQUEST['templateName'])
-                . "', '" . $GLOBALS['dbi']->escapeString($_REQUEST['templateData'])
+                . "'" . $GLOBALS['dbi']->escapeString($_POST['exportType'])
+                . "', '" . $GLOBALS['dbi']->escapeString($_POST['templateName'])
+                . "', '" . $GLOBALS['dbi']->escapeString($_POST['templateData'])
                 . "');";
-            break;
-        case 'load':
-            $query = "SELECT `template_data` FROM " . $templateTable
-                 . " WHERE `id` = " . $id  . " AND `username` = '" . $user . "'";
-            break;
-        case 'update':
-            $query = "UPDATE " . $templateTable . " SET `template_data` = "
-              . "'" . $GLOBALS['dbi']->escapeString($_REQUEST['templateData']) . "'"
-              . " WHERE `id` = " . $id  . " AND `username` = '" . $user . "'";
-            break;
-        case 'delete':
-            $query = "DELETE FROM " . $templateTable
-               . " WHERE `id` = " . $id  . " AND `username` = '" . $user . "'";
-            break;
-        default:
-            $query = '';
-            break;
+                break;
+            case 'load':
+                $query = "SELECT `template_data` FROM " . $templateTable
+                 . " WHERE `id` = " . $id . " AND `username` = '" . $user . "'";
+                break;
+            case 'update':
+                $query = "UPDATE " . $templateTable . " SET `template_data` = "
+                  . "'" . $GLOBALS['dbi']->escapeString($_POST['templateData']) . "'"
+                  . " WHERE `id` = " . $id . " AND `username` = '" . $user . "'";
+                break;
+            case 'delete':
+                $query = "DELETE FROM " . $templateTable
+                   . " WHERE `id` = " . $id . " AND `username` = '" . $user . "'";
+                break;
+            default:
+                $query = '';
+                break;
         }
 
         $result = $this->relation->queryAsControlUser($query, false);
@@ -782,15 +802,16 @@ class Export
         }
 
         $response->setRequestStatus(true);
-        if ('create' == $_REQUEST['templateAction']) {
+        if ('create' == $_POST['templateAction']) {
             $response->addJSON(
                 'data',
-                $this->getOptionsForTemplates($_REQUEST['exportType'])
+                $this->getOptionsForTemplates($_POST['exportType'])
             );
-        } elseif ('load' == $_REQUEST['templateAction']) {
+        } elseif ('load' == $_POST['templateAction']) {
             $data = null;
             while ($row = $GLOBALS['dbi']->fetchAssoc(
-                $result, DatabaseInterface::CONNECT_CONTROL
+                $result,
+                DatabaseInterface::CONNECT_CONTROL
             )) {
                 $data = $row['template_data'];
             }
