@@ -114,11 +114,6 @@ class Header
      */
     private $template;
 
-    /**
-     * @var Navigation
-     */
-    private $navigation;
-
     /**
      * Creates a new class instance
      */
@@ -154,11 +149,6 @@ class Header
         }
 
         $this->userPreferences = new UserPreferences();
-        $this->navigation = new Navigation(
-            $this->template,
-            new Relation($GLOBALS['dbi']),
-            $GLOBALS['dbi']
-        );
     }
 
     /**
@@ -436,7 +426,12 @@ class Header
                 }
 
                 if ($this->_menuEnabled && $GLOBALS['server'] > 0) {
-                    $navigation = $this->navigation->getDisplay();
+                    $nav = new Navigation(
+                        $this->template,
+                        new Relation($GLOBALS['dbi']),
+                        $GLOBALS['dbi']
+                    );
+                    $navigation = $nav->getDisplay();
                 }
 
                 $customHeader = Config::renderHeader();
