@@ -5,6 +5,8 @@
  *
  * @package PhpMyAdmin\Twig
  */
+declare(strict_types=1);
+
 namespace PhpMyAdmin\Twig;
 
 use Twig\Extension\AbstractExtension;
@@ -24,31 +26,27 @@ class UrlExtension extends AbstractExtension
      */
     public function getFunctions()
     {
-        return array(
+        return [
             new TwigFunction(
-                'Url_getHiddenInputs',
+                'get_hidden_inputs',
                 'PhpMyAdmin\Url::getHiddenInputs',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Url_getHiddenFields',
+                'get_hidden_fields',
                 'PhpMyAdmin\Url::getHiddenFields',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Url_getCommon',
+                'get_common',
                 'PhpMyAdmin\Url::getCommon',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
             new TwigFunction(
-                'Url_getCommonRaw',
+                'get_common_raw',
                 'PhpMyAdmin\Url::getCommonRaw',
-                array('is_safe' => array('html'))
+                ['is_safe' => ['html']]
             ),
-            new TwigFunction(
-                'Url_link',
-                'PhpMyAdmin\Core::linkURL'
-            ),
-        );
+        ];
     }
 }
